@@ -7,8 +7,8 @@
 // Author           : Richard C. Bilson and Peter A. Buhr
 // Created On       : Mon Dec 15 14:05:51 2003
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Sat Aug 27 08:26:08 2005
-// Update Count     : 15
+// Last Modified On : Tue Sep 12 08:10:08 2006
+// Update Count     : 16
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -31,7 +31,7 @@
 
 
 #include <uStaticAssert.h>				// _STATIC_ASSERT_
-#include <uAssert.h>					// uAssert
+#include <assert.h>					// assert
 
 #include <cstring>					// ffs, memset
 
@@ -47,12 +47,12 @@ template<int nbits> class uBitSet {
     BaseType bits[ nbase ];
   public:
     void set( int idx ) {
-	uAssert( idx >= 0 && idx < nbits );
+	assert( idx >= 0 && idx < nbits );
 	bits[ idx >> idxshift ] |= ( 1u << ( idx & idxmask ) );
     } // uBitSet::set
 
     void clr( int idx ) {
-	uAssert( idx >= 0 && idx < nbits );
+	assert( idx >= 0 && idx < nbits );
 	bits[ idx >> idxshift ] &= ~( 1u << ( idx & idxmask ) );
     } // uBitSet::clr
 
@@ -65,7 +65,7 @@ template<int nbits> class uBitSet {
     } // uBitSet::clrAll
 
     bool isSet( int idx ) {
-	uAssert( idx >= 0 && idx < nbits );
+	assert( idx >= 0 && idx < nbits );
 	return bits[ idx >> idxshift ] & ( 1u << ( idx & idxmask ) );
     } // uBitSet::is Set
 
@@ -87,7 +87,7 @@ template<int nbits> class uBitSet {
     } // uBitSet::findFirstSet
 
     int operator[]( int i ) const {
-	uAssert( i >= 0 && i < nbase );
+	assert( i >= 0 && i < nbase );
 	return bits[ i ];
     } // uBitSet::operator[]
 }; // uBitSet
@@ -100,12 +100,12 @@ template<> class uBitSet< sizeof( long ) * 8 > {
     enum { nbits = sizeof( long ) * 8 };
   public:
     void set( int idx ) {
-	uAssert( idx >= 0 && idx < nbits );
+	assert( idx >= 0 && idx < nbits );
 	bits |= ( 1ul << idx );
     } // uBitSet::set
 
     void clr( int idx ) {
-	uAssert( idx >= 0 && idx < nbits );
+	assert( idx >= 0 && idx < nbits );
 	bits &= ~( 1ul << idx );
     } // uBitSet::clr
 
@@ -118,7 +118,7 @@ template<> class uBitSet< sizeof( long ) * 8 > {
     } // uBitSet::clrAll
 
     bool isSet( int idx ) {
-	uAssert( idx >= 0 && idx < nbits );
+	assert( idx >= 0 && idx < nbits );
 	return bits & ( 1ul << idx );
     } // uBitSet::is Set
 
@@ -131,7 +131,7 @@ template<> class uBitSet< sizeof( long ) * 8 > {
     } // uBitSet::findFirstSet
 
     int operator[]( int i ) const {
-	uAssert( i == 0 );
+	assert( i == 0 );
 	return bits;
     } // uBitSet::operator[]
 }; // uBitSet
