@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.4.0, Copyright (C) Peter A. Buhr 1994
+// uC++ Version 5.4.1, Copyright (C) Peter A. Buhr 1994
 // 
 // uC++.h -- 
 // 
 // Author           : Peter A. Buhr
 // Created On       : Fri Dec 17 22:04:27 1993
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Mon Sep 25 17:06:55 2006
-// Update Count     : 4651
+// Last Modified On : Wed Nov 22 08:21:41 2006
+// Update Count     : 4652
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -2123,7 +2123,6 @@ class uCluster {
     uCluster &operator=( uCluster & );			// no assignment
 
     void *operator new( size_t, void *storage );
-    void *operator new( size_t size );
   protected:
     const char *name;					// textual name for cluster, default value
     uSpinLock readyIdleTaskLock;			// protect readyTasks, idleProcessors and tasksOnCluster
@@ -2161,6 +2160,8 @@ class uCluster {
     void taskReschedule( uBaseTask &task );
     void closeFD( int fd );
   public:
+    void *operator new( size_t size );			// must be public for normal dynamic "new"
+
     uCluster( unsigned int stacksize = uDefaultStackSize(), const char *name = "*unnamed*" );
     uCluster( const char *name );
     uCluster( uBaseSchedule<uBaseTaskDL> &ReadyQueue, unsigned int stacksize = uDefaultStackSize(), const char *name = "*unnamed*" );
